==> pdfnaut-0.1.0.tar.gz: pdfnaut-0.1.0/tests/test_parsing_files.py <==
# Unit tests for parsing a subset of handcrafted and example files.
import pytest

from pdfnaut.parsers import PdfParser
from pdfnaut.objects import PdfStream, PdfIndirectRef
from pdfnaut.exceptions import PdfParseError


def test_simple_pdf() -> None:
    """Tests a simple PDF. In this context, "simple" means an unencrypted PDF 
    with no compression and few pages of content."""
    with open("tests/docs/sample.pdf", "rb") as data:
        parser = PdfParser(data.read())
        parser.parse()

        assert len(parser.xref) == parser.trailer["Size"]

        catalog = parser.resolve_reference(parser.trailer["Root"])
        metadata = parser.resolve_reference(parser.trailer["Info"])
        assert catalog is not None and metadata is not None
        
        pages = parser.resolve_reference(catalog["Pages"])
        first_page = parser.resolve_reference(pages["Kids"][0])
        first_page_contents = parser.resolve_reference(first_page["Contents"])
        assert isinstance(first_page_contents, PdfStream)


def test_invalid_pdfs() -> None:
    """Tests invalid PDF scenarios. The cases included should all fail."""
    # "PDF" with no header
    with pytest.raises(PdfParseError):
        parser = PdfParser(b"The content doesn't matter. The header not being here does.")
        parser.parse()

    # PDF with an invalid \\Length in stream
    with pytest.raises(PdfParseError):
        with open("tests/docs/pdf-with-bad-stream.pdf", "rb") as data:
            parser = PdfParser(data.read())
            parser.parse()
            parser.resolve_reference(PdfIndirectRef(1, 0))


def test_pdf_with_incremental() -> None:
    """Tests whether an incremental PDF is parsed correctly. Basically, whether the 
    correct trailer is provided and whether the XRefs are merged."""
    with open("tests/docs/pdf2-incremental.pdf", "rb") as data:
        parser = PdfParser(data.read())
        parser.parse()
        
        assert len(parser.update_xrefs) == 2 and len(parser._trailers) == 2
        assert parser.trailer["Size"] == len(parser.xref)


def test_pdf_with_xref_stream() -> None:
    """Tests a PDF document with a compressed XRef stream"""
    with open("tests/docs/compressed-xref.pdf", "rb") as data:
        parser = PdfParser(data.read())
        parser.parse()

        catalog = parser.resolve_reference(parser.trailer["Root"])
        pages = parser.resolve_reference(catalog["Pages"])
        first_page = parser.resolve_reference(pages["Kids"][0])
        stream = parser.resolve_reference(first_page["Contents"]).decompress()

        assert stream.startswith(b"q\n0.000008871 0 595.32 841.92 re\n")

==> pdfnaut-0.1.1.tar.gz: pdfnaut-0.1.1/tests/test_parsing_files.py <==
# Unit tests for parsing a subset of handcrafted and example files.
import pytest

from pdfnaut.parsers import PdfParser
from pdfnaut.objects import PdfStream, PdfIndirectRef
from pdfnaut.exceptions import PdfParseError


def test_simple_pdf() -> None:
    """Tests a simple PDF. In this context, "simple" means an unencrypted PDF 
    with no compression and few pages of content."""
    with open("tests/docs/sample.pdf", "rb") as data:
        parser = PdfParser(data.read())
        parser.parse()

        assert len(parser.xref) == parser.trailer["Size"]

        catalog = parser.resolve_reference(parser.trailer["Root"])
        metadata = parser.resolve_reference(parser.trailer["Info"])
        assert catalog is not None and metadata is not None
        
        pages = parser.resolve_reference(catalog["Pages"])
        first_page = parser.resolve_reference(pages["Kids"][0])
        first_page_contents = parser.resolve_reference(first_page["Contents"])
        assert isinstance(first_page_contents, PdfStream)


def test_invalid_pdfs() -> None:
    """Tests invalid PDF scenarios. The cases included should all fail."""
    # "PDF" with no header
    with pytest.raises(PdfParseError):
        parser = PdfParser(b"The content doesn't matter. The header not being here does.")
        parser.parse()

    # PDF with an invalid \\Length in stream
    with pytest.raises(PdfParseError):
        with open("tests/docs/pdf-with-bad-stream.pdf", "rb") as data:
            parser = PdfParser(data.read())
            parser.parse()
            parser.resolve_reference(PdfIndirectRef(1, 0))


def test_pdf_with_incremental() -> None:
    """Tests whether an incremental PDF is parsed correctly. Basically, whether the 
    correct trailer is provided and whether the XRefs are merged."""
    with open("tests/docs/pdf2-incremental.pdf", "rb") as data:
        parser = PdfParser(data.read())
        parser.parse()
        
        assert len(parser.updates) == 2
        assert parser.trailer["Size"] == len(parser.xref)


def test_pdf_with_xref_stream() -> None:
    """Tests a PDF document with a compressed XRef stream"""
    with open("tests/docs/compressed-xref.pdf", "rb") as data:
        parser = PdfParser(data.read())
        parser.parse()

        catalog = parser.resolve_reference(parser.trailer["Root"])
        pages = parser.resolve_reference(catalog["Pages"])
        first_page = parser.resolve_reference(pages["Kids"][0])
        stream = parser.resolve_reference(first_page["Contents"]).decompress()

        assert stream.startswith(b"q\n0.000008871 0 595.32 841.92 re\n")
